Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Riot.ApplicationA Riot `Application` can be used to encapsulate functionality that must share the same lifecycle. For example, the `Riot.Logger` is an Application.
Applications are also useful to orchestrate the order of startup, since `Riot.start ~apps` will start them one by one.
module type Intf = sig ... end