Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Process.Messagestype monitor = | Process_down of Pid.tThis monitor message reports that a monitored process has terminated.
*)type Message.t += | Monitor of monitorMonitor related messages
*)| Exit of Pid.t * exit_reasonExit signal. If you want this message make sure to set the Trap_exit flag to true with the `process_flag` function.